/*===========================================================================*/
/*   (Reduce/walk.scm)                                                       */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Reduce/walk.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_REDUCE_WALK_TYPE_DEFINITIONS
#define BGL_REDUCE_WALK_TYPE_DEFINITIONS
#endif													// BGL_REDUCE_WALK_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	extern obj_t BGl_za2optimza2z00zzengine_paramz00;
	static obj_t BGl_requirezd2initializa7ationz75zzreduce_walkz00 = BUNSPEC;
	BGL_EXPORTED_DECL obj_t BGl_reducezd2walkz12zc0zzreduce_walkz00(obj_t, obj_t,
		obj_t);
	BGL_IMPORT obj_t bgl_display_obj(obj_t, obj_t);
	BGL_IMPORT bool_t BGl_integerzf3zf3zz__r4_numbers_6_5_fixnumz00(obj_t);
	extern obj_t BGl_internalzd2errorzd2zztools_errorz00(obj_t, obj_t, obj_t);
	static obj_t BGl_genericzd2initzd2zzreduce_walkz00(void);
	extern obj_t BGl_reducezd2csez12zc0zzreduce_csez00(obj_t);
	static obj_t BGl_objectzd2initzd2zzreduce_walkz00(void);
	BGL_IMPORT bool_t BGl_2ze3ze3zz__r4_numbers_6_5z00(obj_t, obj_t);
	extern obj_t BGl_reducezd2conditionalz12zc0zzreduce_condz00(obj_t);
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
		obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzreduce_walkz00(void);
	extern obj_t BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00;
	extern obj_t BGl_removezd2varzd2zzast_removez00(obj_t, obj_t);
	static obj_t BGl_z62reducezd2walkz12za2zzreduce_walkz00(obj_t, obj_t, obj_t,
		obj_t);
	BGL_IMPORT obj_t BGl_exitz00zz__errorz00(obj_t);
	extern obj_t BGl_reducezd2copyz12zc0zzreduce_copyz00(obj_t);
	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzreduce_walkz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_removez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_betaz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_1occz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_flowzd2typeczd2(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_typecz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_condz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_csez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzreduce_copyz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_shapez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_passz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_errorz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_speekz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_output_6_10_3z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
	static obj_t BGl_cnstzd2initzd2zzreduce_walkz00(void);
	static obj_t BGl_libraryzd2moduleszd2initz00zzreduce_walkz00(void);
	static obj_t BGl_importedzd2moduleszd2initz00zzreduce_walkz00(void);
	static obj_t BGl_gczd2rootszd2initz00zzreduce_walkz00(void);
	extern obj_t BGl_reducezd2typezd2checkz12z12zzreduce_typecz00(obj_t);
	extern obj_t BGl_za2optimzd2dataflowzf3za2z21zzengine_paramz00;
	extern obj_t BGl_reducezd21occz12zc0zzreduce_1occz00(obj_t);
	extern obj_t BGl_za2currentzd2passza2zd2zzengine_passz00;
	extern obj_t BGl_verbosez00zztools_speekz00(obj_t, obj_t);
	extern obj_t BGl_reducezd2betaz12zc0zzreduce_betaz00(obj_t);
	extern obj_t BGl_za2optimzd2reducezd2betazf3za2zf3zzengine_paramz00;
	extern obj_t
		BGl_reducezd2flowzd2typezd2checkz12zc0zzreduce_flowzd2typeczd2(obj_t);
	static obj_t __cnst[2];


	   
		 
		DEFINE_STRING(BGl_string1384z00zzreduce_walkz00,
		BgL_bgl_string1384za700za7za7r1401za7, "   . ", 5);
	      DEFINE_STRING(BGl_string1385z00zzreduce_walkz00,
		BgL_bgl_string1385za700za7za7r1402za7, "failure during prelude hook", 27);
	      DEFINE_STRING(BGl_string1386z00zzreduce_walkz00,
		BgL_bgl_string1386za700za7za7r1403za7, " error", 6);
	      DEFINE_STRING(BGl_string1387z00zzreduce_walkz00,
		BgL_bgl_string1387za700za7za7r1404za7, "s", 1);
	      DEFINE_STRING(BGl_string1388z00zzreduce_walkz00,
		BgL_bgl_string1388za700za7za7r1405za7, "", 0);
	      DEFINE_STRING(BGl_string1389z00zzreduce_walkz00,
		BgL_bgl_string1389za700za7za7r1406za7, " occured, ending ...", 20);
	      DEFINE_STRING(BGl_string1390z00zzreduce_walkz00,
		BgL_bgl_string1390za700za7za7r1407za7, "failure during postlude hook", 28);
	      DEFINE_STRING(BGl_string1391z00zzreduce_walkz00,
		BgL_bgl_string1391za700za7za7r1408za7, "reduce_walk", 11);
	      DEFINE_STRING(BGl_string1392z00zzreduce_walkz00,
		BgL_bgl_string1392za700za7za7r1409za7, "reduce pass-started ", 20);
	     
		DEFINE_EXPORT_BGL_PROCEDURE(BGl_reducezd2walkz12zd2envz12zzreduce_walkz00,
		BgL_bgl_za762reduceza7d2walk1410z00, va_generic_entry,
		BGl_z62reducezd2walkz12za2zzreduce_walkz00, BUNSPEC, -3);

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		   
			 ADD_ROOT((void *) (&BGl_requirezd2initializa7ationz75zzreduce_walkz00));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzreduce_walkz00(long
		BgL_checksumz00_1635, char *BgL_fromz00_1636)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzreduce_walkz00))
				{
					BGl_requirezd2initializa7ationz75zzreduce_walkz00 =
						BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zzreduce_walkz00();
					BGl_libraryzd2moduleszd2initz00zzreduce_walkz00();
					BGl_cnstzd2initzd2zzreduce_walkz00();
					BGl_importedzd2moduleszd2initz00zzreduce_walkz00();
					return BGl_methodzd2initzd2zzreduce_walkz00();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			BGl_modulezd2initializa7ationz75zz__r4_output_6_10_3z00(0L,
				"reduce_walk");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(0L,
				"reduce_walk");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5z00(0L, "reduce_walk");
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "reduce_walk");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L, "reduce_walk");
			BGl_modulezd2initializa7ationz75zz__errorz00(0L, "reduce_walk");
			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L, "reduce_walk");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
				"reduce_walk");
			return BUNSPEC;
		}

	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			{	/* Reduce/walk.scm 15 */
				obj_t BgL_cportz00_1624;

				{	/* Reduce/walk.scm 15 */
					obj_t BgL_stringz00_1631;

					BgL_stringz00_1631 = BGl_string1392z00zzreduce_walkz00;
					{	/* Reduce/walk.scm 15 */
						obj_t BgL_startz00_1632;

						BgL_startz00_1632 = BINT(0L);
						{	/* Reduce/walk.scm 15 */
							obj_t BgL_endz00_1633;

							BgL_endz00_1633 =
								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1631)));
							{	/* Reduce/walk.scm 15 */

								BgL_cportz00_1624 =
									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
									(BgL_stringz00_1631, BgL_startz00_1632, BgL_endz00_1633);
				}}}}
				{
					long BgL_iz00_1625;

					BgL_iz00_1625 = 1L;
				BgL_loopz00_1626:
					if ((BgL_iz00_1625 == (-1L)))
						{	/* Reduce/walk.scm 15 */
							return BUNSPEC;
						}
					else
						{	/* Reduce/walk.scm 15 */
							{	/* Reduce/walk.scm 15 */
								obj_t BgL_arg1400z00_1627;

								{	/* Reduce/walk.scm 15 */

									{	/* Reduce/walk.scm 15 */
										obj_t BgL_locationz00_1629;

										BgL_locationz00_1629 = BBOOL(((bool_t) 0));
										{	/* Reduce/walk.scm 15 */

											BgL_arg1400z00_1627 =
												BGl_readz00zz__readerz00(BgL_cportz00_1624,
												BgL_locationz00_1629);
										}
									}
								}
								{	/* Reduce/walk.scm 15 */
									int BgL_tmpz00_1662;

									BgL_tmpz00_1662 = (int) (BgL_iz00_1625);
									CNST_TABLE_SET(BgL_tmpz00_1662, BgL_arg1400z00_1627);
							}}
							{	/* Reduce/walk.scm 15 */
								int BgL_auxz00_1630;

								BgL_auxz00_1630 = (int) ((BgL_iz00_1625 - 1L));
								{
									long BgL_iz00_1667;

									BgL_iz00_1667 = (long) (BgL_auxz00_1630);
									BgL_iz00_1625 = BgL_iz00_1667;
									goto BgL_loopz00_1626;
								}
							}
						}
				}
			}
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			return bgl_gc_roots_register();
		}

	}



/* reduce-walk! */
	BGL_EXPORTED_DEF obj_t BGl_reducezd2walkz12zc0zzreduce_walkz00(obj_t
		BgL_globalsz00_3, obj_t BgL_msgz00_4, obj_t BgL_typezd2unsafezd2_5)
	{
		{	/* Reduce/walk.scm 36 */
			{	/* Reduce/walk.scm 37 */
				obj_t BgL_list1237z00_1360;

				{	/* Reduce/walk.scm 37 */
					obj_t BgL_arg1240z00_1361;

					{	/* Reduce/walk.scm 37 */
						obj_t BgL_arg1241z00_1362;

						BgL_arg1241z00_1362 =
							MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
						BgL_arg1240z00_1361 =
							MAKE_YOUNG_PAIR(BgL_msgz00_4, BgL_arg1241z00_1362);
					}
					BgL_list1237z00_1360 =
						MAKE_YOUNG_PAIR(BGl_string1384z00zzreduce_walkz00,
						BgL_arg1240z00_1361);
				}
				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1237z00_1360);
			}
			BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
			BGl_za2currentzd2passza2zd2zzengine_passz00 = BgL_msgz00_4;
			{	/* Reduce/walk.scm 37 */
				obj_t BgL_g1106z00_1363;

				BgL_g1106z00_1363 = BNIL;
				{
					obj_t BgL_hooksz00_1366;
					obj_t BgL_hnamesz00_1367;

					BgL_hooksz00_1366 = BgL_g1106z00_1363;
					BgL_hnamesz00_1367 = BNIL;
				BgL_zc3z04anonymousza31242ze3z87_1368:
					if (NULLP(BgL_hooksz00_1366))
						{	/* Reduce/walk.scm 37 */
							((obj_t) CNST_TABLE_REF(0));
						}
					else
						{	/* Reduce/walk.scm 37 */
							bool_t BgL_test1422z00_1681;

							{	/* Reduce/walk.scm 37 */
								obj_t BgL_fun1251z00_1375;

								BgL_fun1251z00_1375 = CAR(((obj_t) BgL_hooksz00_1366));
								BgL_test1422z00_1681 =
									CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1251z00_1375));
							}
							if (BgL_test1422z00_1681)
								{	/* Reduce/walk.scm 37 */
									obj_t BgL_arg1246z00_1372;
									obj_t BgL_arg1247z00_1373;

									BgL_arg1246z00_1372 = CDR(((obj_t) BgL_hooksz00_1366));
									BgL_arg1247z00_1373 = CDR(((obj_t) BgL_hnamesz00_1367));
									{
										obj_t BgL_hnamesz00_1693;
										obj_t BgL_hooksz00_1692;

										BgL_hooksz00_1692 = BgL_arg1246z00_1372;
										BgL_hnamesz00_1693 = BgL_arg1247z00_1373;
										BgL_hnamesz00_1367 = BgL_hnamesz00_1693;
										BgL_hooksz00_1366 = BgL_hooksz00_1692;
										goto BgL_zc3z04anonymousza31242ze3z87_1368;
									}
								}
							else
								{	/* Reduce/walk.scm 37 */
									obj_t BgL_arg1249z00_1374;

									BgL_arg1249z00_1374 = CAR(((obj_t) BgL_hnamesz00_1367));
									BGl_internalzd2errorzd2zztools_errorz00(BgL_msgz00_4,
										BGl_string1385z00zzreduce_walkz00, BgL_arg1249z00_1374);
								}
						}
				}
			}
			{	/* Reduce/walk.scm 39 */
				bool_t BgL_test1423z00_1697;

				if (PAIRP(BgL_typezd2unsafezd2_5))
					{	/* Reduce/walk.scm 39 */
						BgL_test1423z00_1697 = CBOOL(CAR(BgL_typezd2unsafezd2_5));
					}
				else
					{	/* Reduce/walk.scm 39 */
						BgL_test1423z00_1697 = ((bool_t) 0);
					}
				if (BgL_test1423z00_1697)
					{	/* Reduce/walk.scm 39 */
						BGl_reducezd21occz12zc0zzreduce_1occz00(BgL_globalsz00_3);
						BGl_reducezd2typezd2checkz12z12zzreduce_typecz00(BgL_globalsz00_3);
						BGl_reducezd2conditionalz12zc0zzreduce_condz00(BgL_globalsz00_3);
						{	/* Reduce/walk.scm 43 */
							obj_t BgL_valuez00_1380;

							BgL_valuez00_1380 =
								BGl_removezd2varzd2zzast_removez00(
								((obj_t) CNST_TABLE_REF(1)), BgL_globalsz00_3);
							if (
								((long)
									CINT(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00) >
									0L))
								{	/* Reduce/walk.scm 43 */
									{	/* Reduce/walk.scm 43 */
										obj_t BgL_port1228z00_1382;

										{	/* Reduce/walk.scm 43 */
											obj_t BgL_tmpz00_1711;

											BgL_tmpz00_1711 = BGL_CURRENT_DYNAMIC_ENV();
											BgL_port1228z00_1382 =
												BGL_ENV_CURRENT_ERROR_PORT(BgL_tmpz00_1711);
										}
										bgl_display_obj
											(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
											BgL_port1228z00_1382);
										bgl_display_string(BGl_string1386z00zzreduce_walkz00,
											BgL_port1228z00_1382);
										{	/* Reduce/walk.scm 43 */
											obj_t BgL_arg1256z00_1383;

											{	/* Reduce/walk.scm 43 */
												bool_t BgL_test1426z00_1716;

												if (BGl_integerzf3zf3zz__r4_numbers_6_5_fixnumz00
													(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
													{	/* Reduce/walk.scm 43 */
														if (INTEGERP
															(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
															{	/* Reduce/walk.scm 43 */
																BgL_test1426z00_1716 =
																	(
																	(long)
																	CINT
																	(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00)
																	> 1L);
															}
														else
															{	/* Reduce/walk.scm 43 */
																BgL_test1426z00_1716 =
																	BGl_2ze3ze3zz__r4_numbers_6_5z00
																	(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
																	BINT(1L));
															}
													}
												else
													{	/* Reduce/walk.scm 43 */
														BgL_test1426z00_1716 = ((bool_t) 0);
													}
												if (BgL_test1426z00_1716)
													{	/* Reduce/walk.scm 43 */
														BgL_arg1256z00_1383 =
															BGl_string1387z00zzreduce_walkz00;
													}
												else
													{	/* Reduce/walk.scm 43 */
														BgL_arg1256z00_1383 =
															BGl_string1388z00zzreduce_walkz00;
													}
											}
											bgl_display_obj(BgL_arg1256z00_1383,
												BgL_port1228z00_1382);
										}
										bgl_display_string(BGl_string1389z00zzreduce_walkz00,
											BgL_port1228z00_1382);
										bgl_display_char(((unsigned char) 10),
											BgL_port1228z00_1382);
									}
									{	/* Reduce/walk.scm 43 */
										obj_t BgL_list1261z00_1387;

										BgL_list1261z00_1387 = MAKE_YOUNG_PAIR(BINT((-1L)), BNIL);
										return BGl_exitz00zz__errorz00(BgL_list1261z00_1387);
									}
								}
							else
								{	/* Reduce/walk.scm 43 */
									obj_t BgL_g1108z00_1388;

									BgL_g1108z00_1388 = BNIL;
									{
										obj_t BgL_hooksz00_1391;
										obj_t BgL_hnamesz00_1392;

										BgL_hooksz00_1391 = BgL_g1108z00_1388;
										BgL_hnamesz00_1392 = BNIL;
									BgL_zc3z04anonymousza31262ze3z87_1393:
										if (NULLP(BgL_hooksz00_1391))
											{	/* Reduce/walk.scm 43 */
												return BgL_valuez00_1380;
											}
										else
											{	/* Reduce/walk.scm 43 */
												bool_t BgL_test1430z00_1733;

												{	/* Reduce/walk.scm 43 */
													obj_t BgL_fun1270z00_1400;

													BgL_fun1270z00_1400 =
														CAR(((obj_t) BgL_hooksz00_1391));
													BgL_test1430z00_1733 =
														CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1270z00_1400));
												}
												if (BgL_test1430z00_1733)
													{	/* Reduce/walk.scm 43 */
														obj_t BgL_arg1266z00_1397;
														obj_t BgL_arg1267z00_1398;

														BgL_arg1266z00_1397 =
															CDR(((obj_t) BgL_hooksz00_1391));
														BgL_arg1267z00_1398 =
															CDR(((obj_t) BgL_hnamesz00_1392));
														{
															obj_t BgL_hnamesz00_1745;
															obj_t BgL_hooksz00_1744;

															BgL_hooksz00_1744 = BgL_arg1266z00_1397;
															BgL_hnamesz00_1745 = BgL_arg1267z00_1398;
															BgL_hnamesz00_1392 = BgL_hnamesz00_1745;
															BgL_hooksz00_1391 = BgL_hooksz00_1744;
															goto BgL_zc3z04anonymousza31262ze3z87_1393;
														}
													}
												else
													{	/* Reduce/walk.scm 43 */
														obj_t BgL_arg1268z00_1399;

														BgL_arg1268z00_1399 =
															CAR(((obj_t) BgL_hnamesz00_1392));
														return
															BGl_internalzd2errorzd2zztools_errorz00
															(BGl_za2currentzd2passza2zd2zzengine_passz00,
															BGl_string1390z00zzreduce_walkz00,
															BgL_arg1268z00_1399);
													}
											}
									}
								}
						}
					}
				else
					{	/* Reduce/walk.scm 39 */
						if (CBOOL(BGl_za2optimzd2dataflowzf3za2z21zzengine_paramz00))
							{	/* Reduce/walk.scm 44 */
								BGl_reducezd2copyz12zc0zzreduce_copyz00(BgL_globalsz00_3);
								if (((long) CINT(BGl_za2optimza2z00zzengine_paramz00) >= 2L))
									{	/* Reduce/walk.scm 46 */
										BGl_reducezd2csez12zc0zzreduce_csez00(BgL_globalsz00_3);
									}
								else
									{	/* Reduce/walk.scm 46 */
										BFALSE;
									}
								BGl_reducezd2typezd2checkz12z12zzreduce_typecz00
									(BgL_globalsz00_3);
								BGl_reducezd2copyz12zc0zzreduce_copyz00(BgL_globalsz00_3);
								BGl_reducezd2conditionalz12zc0zzreduce_condz00
									(BgL_globalsz00_3);
								BGl_reducezd21occz12zc0zzreduce_1occz00(BgL_globalsz00_3);
								if (CBOOL
									(BGl_za2optimzd2reducezd2betazf3za2zf3zzengine_paramz00))
									{	/* Reduce/walk.scm 51 */
										BGl_reducezd2betaz12zc0zzreduce_betaz00(BgL_globalsz00_3);
									}
								else
									{	/* Reduce/walk.scm 51 */
										BFALSE;
									}
								BGl_reducezd2flowzd2typezd2checkz12zc0zzreduce_flowzd2typeczd2
									(BgL_globalsz00_3);
								{	/* Reduce/walk.scm 53 */
									obj_t BgL_valuez00_1404;

									BgL_valuez00_1404 =
										BGl_removezd2varzd2zzast_removez00(
										((obj_t) CNST_TABLE_REF(1)), BgL_globalsz00_3);
									if (
										((long)
											CINT(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00)
											> 0L))
										{	/* Reduce/walk.scm 53 */
											{	/* Reduce/walk.scm 53 */
												obj_t BgL_port1229z00_1406;

												{	/* Reduce/walk.scm 53 */
													obj_t BgL_tmpz00_1770;

													BgL_tmpz00_1770 = BGL_CURRENT_DYNAMIC_ENV();
													BgL_port1229z00_1406 =
														BGL_ENV_CURRENT_ERROR_PORT(BgL_tmpz00_1770);
												}
												bgl_display_obj
													(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
													BgL_port1229z00_1406);
												bgl_display_string(BGl_string1386z00zzreduce_walkz00,
													BgL_port1229z00_1406);
												{	/* Reduce/walk.scm 53 */
													obj_t BgL_arg1274z00_1407;

													{	/* Reduce/walk.scm 53 */
														bool_t BgL_test1435z00_1775;

														if (BGl_integerzf3zf3zz__r4_numbers_6_5_fixnumz00
															(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
															{	/* Reduce/walk.scm 53 */
																if (INTEGERP
																	(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
																	{	/* Reduce/walk.scm 53 */
																		BgL_test1435z00_1775 =
																			(
																			(long)
																			CINT
																			(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00)
																			> 1L);
																	}
																else
																	{	/* Reduce/walk.scm 53 */
																		BgL_test1435z00_1775 =
																			BGl_2ze3ze3zz__r4_numbers_6_5z00
																			(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
																			BINT(1L));
																	}
															}
														else
															{	/* Reduce/walk.scm 53 */
																BgL_test1435z00_1775 = ((bool_t) 0);
															}
														if (BgL_test1435z00_1775)
															{	/* Reduce/walk.scm 53 */
																BgL_arg1274z00_1407 =
																	BGl_string1387z00zzreduce_walkz00;
															}
														else
															{	/* Reduce/walk.scm 53 */
																BgL_arg1274z00_1407 =
																	BGl_string1388z00zzreduce_walkz00;
															}
													}
													bgl_display_obj(BgL_arg1274z00_1407,
														BgL_port1229z00_1406);
												}
												bgl_display_string(BGl_string1389z00zzreduce_walkz00,
													BgL_port1229z00_1406);
												bgl_display_char(((unsigned char) 10),
													BgL_port1229z00_1406);
											}
											{	/* Reduce/walk.scm 53 */
												obj_t BgL_list1277z00_1411;

												BgL_list1277z00_1411 =
													MAKE_YOUNG_PAIR(BINT((-1L)), BNIL);
												return BGl_exitz00zz__errorz00(BgL_list1277z00_1411);
											}
										}
									else
										{	/* Reduce/walk.scm 53 */
											obj_t BgL_g1110z00_1412;

											BgL_g1110z00_1412 = BNIL;
											{
												obj_t BgL_hooksz00_1415;
												obj_t BgL_hnamesz00_1416;

												BgL_hooksz00_1415 = BgL_g1110z00_1412;
												BgL_hnamesz00_1416 = BNIL;
											BgL_zc3z04anonymousza31278ze3z87_1417:
												if (NULLP(BgL_hooksz00_1415))
													{	/* Reduce/walk.scm 53 */
														return BgL_valuez00_1404;
													}
												else
													{	/* Reduce/walk.scm 53 */
														bool_t BgL_test1439z00_1792;

														{	/* Reduce/walk.scm 53 */
															obj_t BgL_fun1286z00_1424;

															BgL_fun1286z00_1424 =
																CAR(((obj_t) BgL_hooksz00_1415));
															BgL_test1439z00_1792 =
																CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1286z00_1424));
														}
														if (BgL_test1439z00_1792)
															{	/* Reduce/walk.scm 53 */
																obj_t BgL_arg1282z00_1421;
																obj_t BgL_arg1284z00_1422;

																BgL_arg1282z00_1421 =
																	CDR(((obj_t) BgL_hooksz00_1415));
																BgL_arg1284z00_1422 =
																	CDR(((obj_t) BgL_hnamesz00_1416));
																{
																	obj_t BgL_hnamesz00_1804;
																	obj_t BgL_hooksz00_1803;

																	BgL_hooksz00_1803 = BgL_arg1282z00_1421;
																	BgL_hnamesz00_1804 = BgL_arg1284z00_1422;
																	BgL_hnamesz00_1416 = BgL_hnamesz00_1804;
																	BgL_hooksz00_1415 = BgL_hooksz00_1803;
																	goto BgL_zc3z04anonymousza31278ze3z87_1417;
																}
															}
														else
															{	/* Reduce/walk.scm 53 */
																obj_t BgL_arg1285z00_1423;

																BgL_arg1285z00_1423 =
																	CAR(((obj_t) BgL_hnamesz00_1416));
																return
																	BGl_internalzd2errorzd2zztools_errorz00
																	(BGl_za2currentzd2passza2zd2zzengine_passz00,
																	BGl_string1390z00zzreduce_walkz00,
																	BgL_arg1285z00_1423);
															}
													}
											}
										}
								}
							}
						else
							{	/* Reduce/walk.scm 44 */
								return
									BGl_removezd2varzd2zzast_removez00(
									((obj_t) CNST_TABLE_REF(1)), BgL_globalsz00_3);
							}
					}
			}
		}

	}



/* &reduce-walk! */
	obj_t BGl_z62reducezd2walkz12za2zzreduce_walkz00(obj_t BgL_envz00_1620,
		obj_t BgL_globalsz00_1621, obj_t BgL_msgz00_1622,
		obj_t BgL_typezd2unsafezd2_1623)
	{
		{	/* Reduce/walk.scm 36 */
			return
				BGl_reducezd2walkz12zc0zzreduce_walkz00(BgL_globalsz00_1621,
				BgL_msgz00_1622, BgL_typezd2unsafezd2_1623);
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzreduce_walkz00(void)
	{
		{	/* Reduce/walk.scm 15 */
			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_copyz00(215645584L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_csez00(347839157L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_condz00(39795278L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_typecz00(433031772L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_flowzd2typeczd2(67029510L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_1occz00(256644222L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			BGl_modulezd2initializa7ationz75zzreduce_betaz00(214257086L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
			return
				BGl_modulezd2initializa7ationz75zzast_removez00(383247627L,
				BSTRING_TO_STRING(BGl_string1391z00zzreduce_walkz00));
		}

	}

#ifdef __cplusplus
}
#endif
